# instance-selection-for-regression
This repo contains the code for various instance selection algorithms
usable with regression models. The implementations are compatible with sklearn and follow
its outlier detection interface.
The repo is not yet finished. More documentation and examples will be added soon.

The SelCon algorithm is taken from the authors and their repo here: https://github.com/abir-de/SELCOn